@@ -1,10 +1,11 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package OpenGbg::Elk;
 
-our $VERSION = '0.1400'; # VERSION
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1401';
 
 use Moose();
 use MooseX::AttributeShortcuts();
@@ -35,7 +36,7 @@ OpenGbg::Elk
 
 =head1 VERSION
 
-Version 0.1400, released 2016-01-28.
+Version 0.1401, released 2016-05-05.
 
 =head1 SOURCE
 
