@@ -1,11 +1,12 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package OpenGbg::Service::AirQuality;
 
-our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: Entry point to the Air Quality service
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1401';
 
 use OpenGbg::Elk;
 use namespace::autoclean;
@@ -63,7 +64,7 @@ OpenGbg::Service::AirQuality - Entry point to the Air Quality service
 
 =head1 VERSION
 
-Version 0.1400, released 2016-01-28.
+Version 0.1401, released 2016-05-05.
 
 =head1 SYNOPSIS
 
