@@ -1,11 +1,12 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package OpenGbg::Service::AirQuality::Measurement;
 
-our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: An air quality measurement
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1401';
 
 use utf8;
 use syntax 'qs';
@@ -14,6 +15,8 @@ use DateTime::Format::HTTP;
 use MooseX::AttributeShortcuts;
 use Types::DateTime qw/DateTime/;
 
+# any attributes/methods added here should also be 'handled' in GetLatestMeasurement.
+
 has_xpath_value _starttime => './x:StartTime';
 has_xpath_value _endtime => './x:StopTime';
 
@@ -390,7 +393,7 @@ OpenGbg::Service::AirQuality::Measurement - An air quality measurement
 
 =head1 VERSION
 
-Version 0.1400, released 2016-01-28.
+Version 0.1401, released 2016-05-05.
 
 =head1 SOURCE
 
