@@ -1,11 +1,12 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package OpenGbg::Service::AirQuality::Measurements;
 
-our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: A list of air quality measurements
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1401';
 
 use XML::Rabbit;
 
@@ -36,7 +37,7 @@ OpenGbg::Service::AirQuality::Measurements - A list of air quality measurements
 
 =head1 VERSION
 
-Version 0.1400, released 2016-01-28.
+Version 0.1401, released 2016-05-05.
 
 =head1 SYNOPSIS
 
