@@ -1,11 +1,12 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package OpenGbg::Service::Bridge;
 
-our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: Entry point to the Bridge service
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1401';
 
 use OpenGbg::Elk;
 use namespace::autoclean;
@@ -45,6 +46,10 @@ sub get_opened_status {
     return OpenGbg::Service::Bridge::GetOpenedStatus->new(xml => $response);
 }
 
+sub is_open {
+    return shift->get_is_currently_open->is_open;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -61,7 +66,7 @@ OpenGbg::Service::Bridge - Entry point to the Bridge service
 
 =head1 VERSION
 
-Version 0.1400, released 2016-01-28.
+Version 0.1401, released 2016-05-05.
 
 =head1 SYNOPSIS
 
