@@ -1,11 +1,12 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package OpenGbg::Service::Bridge::BridgeOpening;
 
-our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: A change in status for Göta Älvbron
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1401';
 
 use XML::Rabbit;
 use DateTime::Format::HTTP;
@@ -54,7 +55,7 @@ OpenGbg::Service::Bridge::BridgeOpening - A change in status for Göta Älvbron
 
 =head1 VERSION
 
-Version 0.1400, released 2016-01-28.
+Version 0.1401, released 2016-05-05.
 
 =head1 SYNOPSIS
 
