@@ -1,11 +1,12 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package OpenGbg::Service::Bridge::GetOpenedStatus;
 
-our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: A list of bridge openings
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1401';
 
 use XML::Rabbit::Root;
 use MooseX::AttributeShortcuts;
@@ -37,7 +38,7 @@ OpenGbg::Service::Bridge::GetOpenedStatus - A list of bridge openings
 
 =head1 VERSION
 
-Version 0.1400, released 2016-01-28.
+Version 0.1401, released 2016-05-05.
 
 =head1 SYNOPSIS
 
