@@ -1,10 +1,11 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package OpenGbg::Service::Getter;
 
-our $VERSION = '0.1400'; # VERSION
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1401';
 
 use Moose::Role;
 use OpenGbg::Exceptions;
@@ -39,7 +40,7 @@ OpenGbg::Service::Getter
 
 =head1 VERSION
 
-Version 0.1400, released 2016-01-28.
+Version 0.1401, released 2016-05-05.
 
 =head1 SOURCE
 
