@@ -1,11 +1,12 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package OpenGbg::Service::StyrOchStall::GetBikeStations;
 
-our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: Get data on all bike stations
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1401';
 
 use XML::Rabbit::Root;
 use DateTime::Format::HTTP;
@@ -68,7 +69,7 @@ OpenGbg::Service::StyrOchStall::GetBikeStations - Get data on all bike stations
 
 =head1 VERSION
 
-Version 0.1400, released 2016-01-28.
+Version 0.1401, released 2016-05-05.
 
 =head1 SYNOPSIS
 
