@@ -1,11 +1,12 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package OpenGbg::Service::StyrOchStall::Station;
 
-our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: Data on a bike station
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1401';
 
 use XML::Rabbit;
 use syntax 'qs';
@@ -96,7 +97,7 @@ OpenGbg::Service::StyrOchStall::Station - Data on a bike station
 
 =head1 VERSION
 
-Version 0.1400, released 2016-01-28.
+Version 0.1401, released 2016-05-05.
 
 =head1 SYNOPSIS
 
