@@ -1,11 +1,12 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package OpenGbg::Service::TrafficCamera;
 
-our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: Entry point to the Traffic Camera service
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1401';
 
 use OpenGbg::Elk;
 
@@ -61,7 +62,7 @@ OpenGbg::Service::TrafficCamera - Entry point to the Traffic Camera service
 
 =head1 VERSION
 
-Version 0.1400, released 2016-01-28.
+Version 0.1401, released 2016-05-05.
 
 =head1 SYNOPSIS
 
