@@ -1,11 +1,12 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package OpenGbg::Service::TrafficCamera::CameraDevice;
 
-our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: Data about a traffic camera
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1401';
 
 use XML::Rabbit;
 use syntax 'qs';
@@ -55,7 +56,7 @@ OpenGbg::Service::TrafficCamera::CameraDevice - Data about a traffic camera
 
 =head1 VERSION
 
-Version 0.1400, released 2016-01-28.
+Version 0.1401, released 2016-05-05.
 
 =head1 SYNOPSIS
 
