@@ -1,11 +1,12 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package OpenGbg::Service::TrafficCamera::GetCameraImage;
 
-our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: Get the current image from a traffic camera
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1401';
 
 use OpenGbg::Elk;
 use namespace::autoclean;
@@ -54,7 +55,7 @@ OpenGbg::Service::TrafficCamera::GetCameraImage - Get the current image from a t
 
 =head1 VERSION
 
-Version 0.1400, released 2016-01-28.
+Version 0.1401, released 2016-05-05.
 
 =head1 SYNOPSIS
 
