@@ -1,11 +1,12 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package OpenGbg::Service::TrafficCamera::GetTrafficCameras;
 
-our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: Get a list of traffic cameras
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1401';
 
 use XML::Rabbit::Root;
 use Types::Standard qw/Str/;
@@ -37,7 +38,7 @@ OpenGbg::Service::TrafficCamera::GetTrafficCameras - Get a list of traffic camer
 
 =head1 VERSION
 
-Version 0.1400, released 2016-01-28.
+Version 0.1401, released 2016-05-05.
 
 =head1 SYNOPSIS
 
